@@ -28,6 +28,9 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <signal.h>
+#include <errno.h>
+
+#include "error.h"
 
 #include "common.h"
 
@@ -44,7 +47,7 @@ START_TEST (test_inspect_command)
 	free (str);
 	pipecmd_free (cmd);
 
-	cmd = pipecmd_new_args ("foo", "bar", "baz quux", NULL);
+	cmd = pipecmd_new_args ("foo", "bar", "baz quux", (void *) 0);
 	str = pipecmd_tostring (cmd);
 	/* TODO: not ideal representation of commands with metacharacters */
 	fail_unless (!strcmp (str, "foo bar baz quux"));
@@ -59,8 +62,8 @@ START_TEST (test_inspect_pipeline)
 	char *str;
 
 	p = pipeline_new ();
-	pipeline_command_args (p, "foo", "bar", NULL);
-	pipeline_command_args (p, "grep", "baz", "quux", NULL);
+	pipeline_command_args (p, "foo", "bar", (void *) 0);
+	pipeline_command_args (p, "grep", "baz", "quux", (void *) 0);
 	fail_unless (pipeline_get_ncommands (p) == 2);
 	pipecmd_setenv (pipeline_get_command (p, 1), "KEY", "value");
 	str = pipeline_tostring (p);
@@ -72,6 +75,16 @@ END_TEST
 
 static void pid_helper (void *data PIPELINE_ATTR_UNUSED)
 {
+	struct sigaction sa;
+
+	/* Get rid of check's SIGTERM handler. */
+	memset (&sa, 0, sizeof sa);
+	sa.sa_handler = SIG_DFL;
+	sigemptyset (&sa.sa_mask);
+	sa.sa_flags = 0;
+	if (sigaction (SIGTERM, &sa, NULL) == -1)
+		error (1, errno, "can't install SIGTERM handler");
+
 	printf ("%ld\n", (long) getpid ());
 	fflush (stdout);
 	pause ();
@@ -99,18 +112,12 @@ START_TEST (test_inspect_pid)
 	 * that's sufficiently portable.
 	 */
 	if (pid == pipeline_get_pid (p, 0)) {
-		FILE *saved_stderr;
 		int status;
 
-		/* Suppress "Terminated" errors.  We should probably have a
-		 * cleaner way to do this.
-		 */
-		saved_stderr = stderr;
-		stderr = fopen ("/dev/null", "w");
+		/* Suppress "Terminated" errors. */
+		setenv ("PIPELINE_QUIET", "1", 1);
 		kill (pid, SIGTERM);
 		status = pipeline_wait (p);
-		fclose (stderr);
-		stderr = saved_stderr;
 
 		fail_unless (status == 128 + SIGTERM,
 			     "pid_helper did not indicate SIGTERM");
